@@ -399,6 +399,35 @@ class TimeWindow(object):
         items.sort()
         writer.writerows(items)
 
+    def report_categories(self, output, categories):
+        """A helper method that lists time spent per category.
+
+        Use this to add a section in a report looks similar to this:
+
+        Administration:  2 hours 1 min
+        Coding:          18 hours 45 min
+        Learning:        3 hours
+
+        category is a dict of entries (<category name>: <duration>).
+        """
+        print >> output
+        print >> output, "By category:"
+        print >> output
+
+        items = categories.items()
+        items.sort()
+        for cat, duration in items:
+            if not cat:
+                continue
+
+            print >> output, u"%-62s  %s" % (
+                cat, format_duration_long(duration))
+
+        if None in categories:
+            print >> output, u"%-62s  %s" % (
+                '(none)', format_duration_long(categories[None]))
+        print >> output
+
     def daily_report(self, output, email, who):
         """Format a daily report.
 
@@ -464,12 +493,22 @@ class TimeWindow(object):
             print >> output, "                time"
         work, slack = self.grouped_entries()
         total_work, total_slacking = self.totals()
+        categories = {}
         if work:
             work = [(entry, duration) for start, entry, duration in work]
             work.sort()
             for entry, duration in work:
                 if not duration:
                     continue # skip empty "arrival" entries
+
+                if ': ' in entry:
+                    cat, task = entry.split(': ', 1)
+                    categories[cat] = categories.get(
+                        cat, datetime.timedelta(0)) + duration
+                else:
+                    categories[None] = categories.get(
+                        None, datetime.timedelta(0)) + duration
+
                 entry = entry[:1].upper() + entry[1:]
                 if estimated_column:
                     print >> output, (u"%-46s  %-14s  %s" %
@@ -481,6 +520,9 @@ class TimeWindow(object):
         print >> output, ("Total work done this week: %s" %
                           format_duration_long(total_work))
 
+        if categories:
+            self.report_categories(output, categories)
+
     def monthly_report(self, output, email, who):
         """Format a monthly report.
 
@@ -527,23 +569,7 @@ class TimeWindow(object):
                           format_duration_long(total_work))
 
         if categories:
-            print >> output
-            print >> output, "By category:"
-            print >> output
-
-            items = categories.items()
-            items.sort()
-            for cat, duration in items:
-                if not cat:
-                    continue
-
-                print >> output, u"%-62s  %s" % (
-                    cat, format_duration_long(duration))
-
-            if None in categories:
-                print >> output, u"%-62s  %s" % (
-                    '(none)', format_duration_long(categories[None]))
-            print >> output
+            self.report_categories(output, categories)
 
 
 class TimeLog(object):
@@ -732,9 +758,9 @@ class Settings(object):
     email = 'activity-list@example.com'
     name = 'Anonymous'
 
-    editor = 'gvim'
-    mailer = 'x-terminal-emulator -e mutt -H %s'
-    spreadsheet = 'oocalc %s'
+    editor = 'xdg-open'
+    mailer = 'x-terminal-emulator -e "mutt -H %s"'
+    spreadsheet = 'xdg-open %s'
 
     enable_gtk_completion = True  # False enables gvim-style completion
 
@@ -1458,9 +1484,14 @@ class MainWindow(object):
         model = treeview.get_model()
         task = model[path][1]
         self.task_entry.set_text(task)
-        self.task_entry.grab_focus()
-        self.task_entry.set_position(-1)
-        # XXX: how does this integrate with history?
+        def grab_focus():
+            self.task_entry.grab_focus()
+            self.task_entry.set_position(-1)
+        # There's a race here: sometimes the GDK_2BUTTON_PRESS signal is handled
+        # _after_ row-activated, which makes the tree control steal the focus
+        # back from the task entry.  To avoid this, wait until all the events
+        # have been handled.
+        gobject.idle_add(grab_focus)
 
     def task_list_button_press(self, menu, event):
         if event.button == 3:
